@@ -26,8 +26,8 @@ package
 package Data::Dumper::Interp;
 
 { no strict 'refs'; ${__PACKAGE__."::VER"."SION"} = 997.999; }
-our $VERSION = '6.012'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
-our $DATE = '2023-11-22'; # DATE from Dist::Zilla::Plugin::OurDate
+our $VERSION = '7.001'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
+our $DATE = '2023-12-13'; # DATE from Dist::Zilla::Plugin::OurDate
 
 use Moose;
 
@@ -252,9 +252,9 @@ $Foldwidth1     = undef        unless defined $Foldwidth1; # override for 1st
 
 # The following override Data::Dumper defaults
 # Initial D::D values are captured once when we are first loaded.
-#
-#$Useqq          = "unicode:controlpic" unless defined $Useqq;
-$Useqq          = "unicode"    unless defined $Useqq;
+
+#$Useqq          = "<unicode:controlpic>" unless defined $Useqq;
+$Useqq          = "<unicode>"    unless defined $Useqq;
 $Quotekeys      = 0            unless defined $Quotekeys;
 $Sortkeys       = \&__sortkeys unless defined $Sortkeys;
 $Maxdepth       = $Data::Dumper::Maxdepth   unless defined $Maxdepth;
@@ -480,13 +480,16 @@ sub __getself_h {
   $obj->Values([{@_}])
 }
 
-sub _EnabSpacedots {
-  # Append :spacedots to Useqq if Useqq matches the global default
-  # (and if the default used extended options).
-  my $self = shift;
+sub _EnabUseqqFeature {
+  # Append <feature> to Useqq ONLY if Useqq has not been changed
+  # (indicated by "(parens)" in the value -- see $Useqq = ... )
+  # Does nothing unless the default enables extended features.
+  my ($self, $feature) = @_;
   my $curr = $self->Useqq;
-  return $self if length($curr//"") <= 1 or $curr eq $Useqq;
-  $self->Useqq($curr.":spacedots")
+  return $self if length($curr//"") <= 1
+                    || substr($curr,0,1) ne "<"
+                    || substr($curr,-1,1) ne ">";
+  $self->Useqq($curr.$feature)
 }
 
 sub _generate_sub($;$) {
@@ -552,7 +555,8 @@ sub _generate_sub($;$) {
       $code .= " { \@_ = ( &__getself" ;
     }
     elsif ($basename eq "dvis") {
-      $code .= " { \@_ = ( &__getself->_EnabSpacedots" ;
+      $code .= " { \@_ = ( &__getself->_EnabUseqqFeature(':spacedots:condense')" ;
+      #$code .= " { \@_ = ( &__getself->_EnabUseqqFeature(':spacedots')" ;
     }
     else { oops }
 
@@ -649,7 +653,7 @@ my  $my_maxdepth;
 our $my_visit_depth = 0;
 
 my ($maxstringwidth, $truncsuffix, $objects, $opt_refaddr, $listform, $debug);
-my ($sortkeys, $show_overloaded_classname);
+my ($sortkeys, $show_classname);
 
 sub _Do {
   oops unless @_ == 1;
@@ -665,14 +669,14 @@ sub _Do {
   $maxstringwidth = 0 if ($maxstringwidth //= 0) >= INT_MAX;
   $truncsuffix //= "...";
   if (ref($objects) eq "HASH") {
-    for (qw/show_overloaded_classname objects/) {
+    for (qw/show_classname objects/) {
       croak "Objects value is a hashref but '${_}' key is missing\n"
         unless exists $objects->{$_};
     }
-    $show_overloaded_classname = $objects->{show_overloaded_classname};
+    $show_classname = $objects->{show_classname};
     $objects = $objects->{objects};
   } else {
-    $show_overloaded_classname = 1;
+    $show_classname = 1;
   }
   $objects = [ $objects ] unless ref($objects //= []) eq 'ARRAY';
 
@@ -790,7 +794,7 @@ btw '@@@repl obj is overloaded' if $debug;
         # overloaded package; should not happen in this case.
         warn("Recursive overloads on $item ?\n"),last
           if $overload_depth++ > 10;
-        my $cn = $show_overloaded_classname ? "($class)" : "";
+        my $cn = $show_classname ? "($class)" : "";
         # Stringify objects which have the stringification operator
         if (overload::Method($class,'""')) {
           my $prefix = _show_as_number($item) ? _MAGIC_NOQUOTES_PFX : "";
@@ -1283,7 +1287,8 @@ sub __change_quotechars($) {  # edits $_
 }
 
 my %qqesc2controlpic = (
-  '\0' => "\N{SYMBOL FOR NULL}",
+  '\0' => "\N{SYMBOL FOR NULL}",   # occurs if next char is not a digit
+  '\000' => "\N{SYMBOL FOR NULL}", # occurs if next char is a digit
   '\a' => "\N{SYMBOL FOR BELL}",
   '\b' => "\N{SYMBOL FOR BACKSPACE}",
   '\e' => "\N{SYMBOL FOR ESCAPE}",
@@ -1303,7 +1308,8 @@ my %char2controlpic = (
 sub __subst_controlpic_backesc() {  # edits $_
   # Replace '\t' '\n' etc. escapes with "control picture" characters
   return unless/^"/;
-  s{ \G (?: [^\\]++ | \\[^0abefnrt] )*+ \K ( \\[abefnrt] | \\0(?![0-7]) )
+  s{ \G (?: [^\\]++ | \\[^0abefnrt] )*+ \K
+        ( \\[abefnrt] | \\0(?![0-7]) | \\[0-3][0-7][0-7] )
    }{
       $qqesc2controlpic{$1} // $1
     }xesg;
@@ -1315,6 +1321,39 @@ sub __subst_spacedots() {  # edits $_
   }
 }
 
+our $COND_LB = "\N{LEFT DOUBLE PARENTHESIS}";
+our $COND_RB = "\N{RIGHT DOUBLE PARENTHESIS}";
+our $COND_MULT = "\N{MULTIPLICATION SIGN}";
+#my $singlechar_restr = "[^\\\\${COND_LB}${COND_RB}]";
+my $singlechar_restr = "[^\\\\${COND_LB}${COND_RB}${COND_MULT}]";
+
+sub __condense_strings($) {  # edits $_
+  if (/^"/) {
+    my $minrep_m1 = $_[0] - 1;
+
+    # Special case a string of nul represented as \n\n\n...\00n (n=0..7)
+    # D::D generates this to avoid ambiguity if a digit follows
+    s<( (\\([0-7])){$minrep_m1,}\\00\g{-1} )>
+     < $COND_LB."${2}${COND_MULT}".((length($1)-2)/length($2)).$COND_RB >xge;
+
+    # \0 \1 ... if there is no digit following, which makes it ambiguous
+    s<( (\\\d) \g{-1}{$minrep_m1,} ) (?![0-7]) >
+     < $COND_LB."${2}${COND_MULT}".(length($1)/length($2)).$COND_RB >xge;
+
+    # \x for almost any x besides a digit or \
+    s<( ($singlechar_restr | \\\D | \\[0-3][0-7][0-7] | \\x\{[^\{\}]+\})
+        \g{-1}{$minrep_m1,} )
+     >
+     < $COND_LB."${2}${COND_MULT}".(length($1)/length($2)).$COND_RB >xge;
+  }
+}
+
+sub __nums_with_underscores() {
+  if (looks_like_number($_)) {
+    while( s/^([^\._]*?\d)(\d\d\d)(?=$|\.|_)/$1_$2/ ) { }
+  }
+}
+
 my $indent_unit;
 
 sub _mycallloc(;@) {
@@ -1335,8 +1374,10 @@ sub _postprocess_DD_result {
     = @$self{qw/Debug _Listform Foldwidth Foldwidth1/};
   my $useqq = $self->Useqq();
   my $unesc_unicode = $useqq =~ /utf|unic/;
+  my $condense_strings = $useqq =~ /cond/;
   my $controlpics   = $useqq =~ /pic/;
   my $spacedots     = $useqq =~ /space/;
+  my $underscores   = $useqq =~ /_/;
   my $qq            = $useqq =~ /qq(?:=(..))?/ ? ($1//'{}') : '';
   my $pad = $self->Pad() // "";
 
@@ -1362,7 +1403,9 @@ sub _postprocess_DD_result {
     __unesc_unicode          if $unesc_unicode;
     __subst_controlpic_backesc      if $controlpics;
     __subst_spacedots        if $spacedots;
+    __condense_strings(8)    if $condense_strings;
     __change_quotechars($qq) if $qq;
+    __nums_with_underscores  if $underscores;
 
     if ($prepending) { $_ = $prepending . $_; $prepending = ""; }
 
@@ -1953,7 +1996,7 @@ sub DB_Vis_Eval($$) {
     local $Data::Dumper::Interp::string_to_eval =
       "package $pkg; "
        # N.B. eval first clears $@ so we must restore $@ inside the eval
-     .' &Data::Dumper::Interp::_RestorePunct_NoPop;'  # saved in _Interpolate
+     .' &Data::Dumper::Interp::_RestorePunct_NoPop();'  # saved in _Interpolate
        # In case something carps or croaks (e.g. because of ${\(somefunc())}
        # or a tie handler), force a full backtrace so the user's call location
        # is visible.  Unfortunately there is no way to make carp() show only
@@ -2022,7 +2065,7 @@ Data::Dumper::Interp - interpolate Data::Dumper output into strings for human co
   say hvis %hash;    # (abc => [1,2,3,4,5], def => undef)
 
   # Format a reference with abbreviated referent address
-  say visr $href;    # HASH<457:1c9>{abc => [1,2,3,4,5], ...}
+  say visr $ref;     # HASH<457:1c9>{abc => [1,2,3,4,5], ...}
 
   # Just abbreviate a referent address or arbitrary number
   say addrvis refaddr($ref);  # 457:1c9
@@ -2084,14 +2127,13 @@ with pre- and post-processing to "improve" the results:
 
 =over 2
 
-=item * Output is 1 line if possible,
-otherwise folded at your terminal width, WITHOUT a trailing newline.
+=item * One line if possible, else folded to terminal with, WITHOUT newline.
 
 =item * Safely printable Unicode characters appear as themselves.
 
-=item * Object internals are not shown by default; Math:BigInt etc. are stringified.
+=item * Objects like Math:BigInt etc. are stringified (by default).
 
-=item * "virtual" values behind overloaded deref operators are shown.
+=item * "Virtual" values behind overloaded deref operators are shown.
 
 =item * Data::Dumper bugs^H^H^H^Hquirks are circumvented.
 
@@ -2124,13 +2166,11 @@ from interpolating it beforehand.
 
 =head2 dvis I<'string to be interpolated'>
 
-Like C<ivis> but interpolations are prefixed with a "expr=" label
-and spaces are shown visibly as '·'.
+The 'd' is for "B<d>ebugging".  Like C<ivis> but labels expansions
+with "expr=" and shows spaces visibly as '·'.  Other debug-oriented
+formatting may also occur (TBD).
 
-The 'd' in 'dvis' stands for B<d>ebugging messages, a frequent use case where
-brevity of typing is needed.
-
-=head2 vis [I<SCALAREXPR>]
+=head2 vis [I<SCALAREXPR>B<]>
 
 =head2 avis I<LIST>
 
@@ -2159,7 +2199,7 @@ The available modifier characters are:
 
 =over 2
 
-B<l> - omit parenthesis to return a bare list (only with "avis" or "hvis")
+B<l> - omit parenthesis to return a bare list (with "avis" or "hvis")
 
 B<o> - show object internals
 
@@ -2183,7 +2223,7 @@ B<r> - show abbreviated addresses of objects and other refs
 
 =over
 
-Calling B<< Reftype(1) >> using the OO api has the same effect.
+Calling B<< Refaddr(1) >> using the OO api has the same effect.
 
 =back
 
@@ -2198,7 +2238,7 @@ Calling B<< Maxdepth(NUMBER) >> using the OO api has the same effect.
 =back
 
 Functions must be imported explicitly
-unless they are imported by default (list shown below)
+unless they are imported by default (see list below)
 or created via the :all tag.
 
 To avoid having to import functions in advance, you can
@@ -2212,13 +2252,12 @@ use them as methods and import only the C<visnew> function:
   say visnew->avis2lrq(@ARGV);
   etc.
 
-(C<visnew> creates a new object.  Non-existent methods are auto-generated when
-first called via the AUTOLOAD mechanism).
+(C<visnew> creates a new object.  Non-existent methods are auto-generated
+via the AUTOLOAD mechanism).
 
 =head2 Functions imported by default
 
  ivis  dvis    vis  avis  hvis
-
  ivisq dvisq   visq avisq hvisq rvis rvisq
 
  visnew
@@ -2230,8 +2269,8 @@ Z<> Z<>
 
   use Data::Dumper::Interp qw/:all/;
 
-This generates and imports all possible variations using suffix
-characters in alphabetical order, without underscores, with NUMBER <= 2.
+This generates and imports all possible variations using only suffix
+characters, in alphabetical order, with NUMBER <= 2.
 There are 119 variations, too many to remember.
 
 You only need to know the basic names
@@ -2260,20 +2299,20 @@ The C<:debug> import tag prints messages chronicling these events.
 
 =head2 addrvis I<REF_or_NUMBER>
 
-This function returns a string representing an address in both decimal and
+Returns a string showing an address in both decimal and
 hexadecimal, but abbreviated to only the last few digits.
 
 The number of digits starts at 3 and increases over time if necessary
 to keep new results unambiguous.
 
 For REFs, the result is like I<< "HASHE<lt>457:1c9E<gt>" >>
-or, for blessed objects, I<< "Package::NameE<lt>457:1c9E<gt>" >>.
+or I<< "Package::NameE<lt>457:1c9E<gt>" >>.
 
 If the argument is a plain number, just the abbreviated address
 is returned, e.g. I<< "E<lt>457:1c9E<gt>" >>.
 
 I<"undef"> is returned if the argument is undefined.
-Croaks if the argument is defined but not a ref.
+Croaks if the argument is defined but not a number or reference.
 
 C<addrvis_digits(NUMBER)> forces a minimum width
 and C<addrvis_forget()> discards past values and resets to 3 digits.
@@ -2290,7 +2329,7 @@ Like C<addrvis> but omits the <angle brackets>.
 
 These create an object initialized from the global configuration
 variables listed below.  No arguments are permitted.
-C<visnew> is simply a shorthand wrapper.
+C<visnew> is simply a shorthand.
 
 B<All the functions described above> and any variations
 may be called as I<methods> on an object
@@ -2354,13 +2393,13 @@ the object replaced by the result, and the check repeated.
 By default, "(classname)" is prepended when an overloaded operator is
 evaluated to make clear what happened.
 
-=head2 Objects(I<< {objects => VALUE, show_overloaded_classname => BOOL} >>)
+=head2 Objects(I<< {objects => VALUE, show_classname => BOOL} >>)
 
 This form, passing a hashref,
 allows control of whether "(classname)" is prepended to the result
 from an overloaded operator.
 
-If the I<show_overloaded_classname> value is false, then overload results
+If the I<show_classname> value is false, then overload results
 will appear unadorned, i.e. they will look as if the overload result
 was the original value.
 
@@ -2377,7 +2416,7 @@ value, e.g. "A.20" sorts before "A.100".  See C<Data::Dumper> documentation.
 0 means generate 'single quoted' strings when possible.
 
 1 means generate "double quoted" strings as-is from Data::Dumper.
-Non-ASCII charcters will be shown as hex escapes.
+Non-ASCII charcters will be shown as hex or octal escapes.
 
 Otherwise generate "double quoted" strings enhanced according to option
 keywords given as a :-separated list, e.g. Useqq("unicode:controlpics").
@@ -2406,6 +2445,14 @@ set C<Useqq> to just "unicode";
 
 Space characters are shown as '·' (Middle Dot).
 
+=item "condense"
+
+Condense long strings.  For example, 42 repeated 'A's appear as "⸨Ax42⸩".
+
+=item "underscores"
+
+Show numbers with '_' seprating groups of 3 digits.
+
 =item "qq"
 
 =item "qq=XY"
